@@ -25,6 +25,8 @@
 #'   the boundaries of the wavebands.
 #' @param allow.scaled logical indicating whether scaled or normalized spectra
 #'   as argument to spct are flagged as an error.
+#' @param naming character one of "long", "default", "short" or "none". Used to
+#'   select the type of names to assign to returned value.
 #' @param ... other arguments (possibly ignored)
 #'
 #' @note Formal parameter \code{allow.scaled} is used internally for calculation
@@ -36,7 +38,10 @@
 #'   \code{w.band}. A \code{data.frame} in the case of collections of spectra,
 #'   containing one column for each \code{waveband} object, an index column with
 #'   the names of the spectra, and optionally additional columns with metadata
-#'   values retrieved from the attributes of the member spectra.
+#'   values retrieved from the attributes of the member spectra. If
+#'   \code{naming = "long"} the names generated reflect both quantity and
+#'   waveband, if \code{naming = "short"}, names are based only on the wavebands,
+#'   and if \code{naming = "none"} the returned vector has no names.
 #'
 #'   By default values are only integrated, but depending on the argument passed
 #'   to parameter \code{quantity} they can be re-expressed as relative fractions
@@ -99,8 +104,31 @@ irrad.source_spct <-
            wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = getOption("photobiology.use.hinges"),
-           allow.scaled = !quantity  %in% c("average", "mean", "total"),
+           allow.scaled = !quantity %in% c("average", "mean", "total"),
+           naming = "default",
            ...) {
+    if (unit.out == "quantum") {
+      unit.out <- "photon"
+    }
+    if (quantity == "total") {
+      summary.name <- switch(unit.out,
+                             photon = "Q",
+                             energy = "E")
+    } else if (quantity %in% c("average", "mean")) {
+      summary.name <- switch(unit.out,
+                             photon = "Q(wl)",
+                             energy = "E(wl)")
+    } else if (quantity %in% c("contribution", "contribution.pc")) {
+      summary.name <- switch(unit.out,
+                             photon = "Q/Qtot",
+                             energy = "E/Etot")
+    } else if (quantity %in% c("relative", "relative.pc")) {
+      summary.name <- switch(unit.out,
+                             photon = "Q/Qsum",
+                             energy = "E/Esum")
+    } else {
+      stop("Unrecognized 'quantity' : \"", quantity, "\"")
+    }
     # we look for multiple spectra and return with a warning
     num.spectra <- getMultipleWl(spct)
     if (num.spectra != 1) {
@@ -135,33 +163,9 @@ irrad.source_spct <-
       warning("'unit.out' set to an invalid value")
       return(NA_real_)
     }
-    if (unit.out == "quantum") {
-      unit.out <- "photon"
-    }
-    if (is.numeric(w.band)) {
-      w.band <- waveband(w.band)
-    }
-    if (length(w.band) == 0) {
-      w.band <- waveband(spct)
-    }
-    if (is.waveband(w.band)) {
-      # if the argument is a single w.band, we enclose it in a list
-      # so that the for loop works as expected.This is a bit of a
-      # kludge but lets us avoid treating it as a special case
-      w.band <- list(w.band)
-    }
-    w.band <- trim_waveband(w.band = w.band, range = spct, trim = wb.trim)
-    # we check if the list elements are named, if not we set a flag
-    # and an empty vector that will be later filled in with data from
-    # the waveband definitions.
-    wb.number <- length(w.band) # number of wavebands in list
-    wb.name <- names(w.band) # their names in the list
-    if (is.null(wb.name)) {
-      wb.name <- character(wb.number)
-    }
 
     # "source_spct" objects are not guaranteed to contain spectral irradiance
-    # expressed in the needed type of scale.
+    # expressed in the needed units.
     if (unit.out == "energy") {
       q2e(spct, byref = TRUE)
       w.length <- spct[["w.length"]]
@@ -171,23 +175,37 @@ irrad.source_spct <-
       w.length <- spct[["w.length"]]
       s.irrad <- spct[["s.q.irrad"]]
     } else {
-      stop("Unrecognized value for unit.out")
+      stop("Unrecognized value", unit.out, " for unit.out")
     }
 
-    # if the w.band includes 'hinges' we insert them
-    # choose whether to use hinges or not
-    # if the user has specified its value, we leave it alone
-    # but if it was not requested, we decide whether to use
-    # it or not based of the wavelength resolution of the
-    # spectrum. This will produce small errors for high
-    # spectral resolution data, and speed up the calculations
-    # a lot in such cases
+    if (length(w.band) == 0) {
+      # whole range of spectrum
+      w.band <- waveband(spct)
+    }
+    if (is.numeric(w.band)) {
+      # range of wavelengths
+      w.band <- waveband(w.band)
+    }
+    if (is.waveband(w.band)) {
+      # if the argument is a single w.band, we enclose it in a list
+      # so that it can be handled below as a normal case.
+      w.band <- list(w.band)
+    }
+    # we trim the wavebands so that they are within the range of spct
+    w.band <- trim_waveband(w.band = w.band, range = spct, trim = wb.trim)
+    # if the elements of the list are named we collect them
+    wb.number <- length(w.band) # number of wavebands in list
+    wb.name <- names(w.band) # their names in the list
+    # if no names returned, we fill the vector with "".
+    if (is.null(wb.name)) {
+      wb.name <- character(wb.number)
+    }
+
+    # hinges
     if (is.null(use.hinges)) {
        use.hinges <- auto_hinges(w.length)
     }
-
     # we collect all hinges and insert them in one go
-
     if (use.hinges) {
       all.hinges <- NULL
       for (wb in w.band) {
@@ -198,8 +216,8 @@ irrad.source_spct <-
       s.irrad <- lst[["y"]]
     }
 
-    # We iterate through the list of wavebands collecting the integrated irradiances,
-    # possibly weighted depending on the waveband definition
+    # We iterate through the list of wavebands collecting the irradiances,
+    # and waveband names.
     irrad <- numeric(wb.number)
     i <- 0L
     is.effective.spectrum <- is_effective(spct)
@@ -207,7 +225,11 @@ irrad.source_spct <-
       i <- i + 1L
       # get names from wb if needed
       if (wb.name[i] == "") {
-        wb.name[i] <- wb$name
+        if (naming == "short") {
+          wb.name[i] <- labels(wb)[["label"]] # short name
+        } else {
+          wb.name[i] <- labels(wb)[["name"]] # full name
+        }
       }
       if (is.effective.spectrum && is_effective(wb)) {
         warning("Effective spectral irradiance is not compatible with a BSWF: ",
@@ -215,7 +237,7 @@ irrad.source_spct <-
         irrad[i] <- NA_real_
       } else {
         if (is.effective.spectrum) {
-          wb.name[i] <- paste(getBSWFUsed(spct), "*", wb.name[i])
+          wb.name[i] <- paste(getBSWFUsed(spct), "*", wb.name[i], sep = "")
         }
         wl.selector <- which(w.length >= min(wb) & w.length <= max(wb))
         if (wl.selector[1] > 1) {
@@ -244,13 +266,15 @@ irrad.source_spct <-
                 "' not supported when using BSWFs, returning 'total' instead")
         quantity <- "total"
       } else {
+        # recursive call
         total <- irrad_spct(spct, w.band = NULL,
                             unit.out = unit.out,
                             quantity = "total",
                             time.unit = time.unit,
                             use.cached.mult = use.cached.mult,
                             wb.trim = wb.trim,
-                            use.hinges = use.hinges)
+                            use.hinges = use.hinges,
+                            naming = naming)
         irrad <- irrad / total
         if (quantity == "contribution.pc") {
           irrad <- irrad * 1e2
@@ -274,11 +298,16 @@ irrad.source_spct <-
       warning("'quantity '", quantity, "' is invalid, returning 'total' instead")
       quantity <- "total"
     }
+
     if (length(irrad) == 0) {
       irrad <- NA_real_
       names(irrad) <- "out of range"
-    } else {
-      names(irrad) <- paste(names(irrad), wb.name)
+    } else if (naming %in% c("long", "default")) {
+      names(irrad) <- paste(summary.name, wb.name, sep = "_")
+    } else if (naming == "short") {
+      names(irrad) <- wb.name
+    } else if (naming != "none") {
+      warning("Argument to 'naming' unrecognized, assuming \"none\".")
     }
 
     if (length(scale.factor)  == 1L ||
@@ -296,7 +325,7 @@ irrad.source_spct <-
       attr(irrad, "radiation.unit") <-
               paste(unit.out, "irradiance", quantity, "effective:", getBSWFUsed(spct))
     } else {
-      attr(irrad, "radiation.unit") <- paste(unit.out, "irradiance", quantity)
+      attr(irrad, "radiation.unit") <- paste(quantity, unit.out, "irradiance")
     }
 
     irrad
@@ -328,6 +357,8 @@ irrad_spct <- irrad.source_spct
 #'   the boundaries of the wavebands.
 #' @param allow.scaled logical indicating whether scaled or normalized spectra
 #'   as argument to spct are flagged as an error.
+#' @param naming character one of "long", "default", "short" or "none". Used to
+#'   select the type of names to assign to returned value.
 #' @param ... other arguments (possibly used by derived methods).
 #'
 #' @export
@@ -405,13 +436,15 @@ e_irrad.source_spct <-
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
            allow.scaled = !quantity  %in% c("average", "mean", "total"),
+           naming = "default",
            ...) {
     irrad_spct(spct, w.band = w.band, unit.out = "energy",
                scale.factor = scale.factor,
                quantity = quantity,
                time.unit = time.unit, wb.trim = wb.trim,
                use.cached.mult = use.cached.mult, use.hinges = use.hinges,
-               allow.scaled = allow.scaled)
+               allow.scaled = allow.scaled,
+               naming = naming)
   }
 
 # photon irradiance -------------------------------------------------------
@@ -438,6 +471,8 @@ e_irrad.source_spct <-
 #'   the boundaries of the wavebands.
 #' @param allow.scaled logical indicating whether scaled or normalized spectra
 #'   as argument to spct are flagged as an error.
+#' @param naming character one of "long", "default", "short" or "none". Used to
+#'   select the type of names to assign to returned value.
 #' @param ... other arguments (possibly ignored).
 #'
 #' @export
@@ -507,13 +542,15 @@ q_irrad.source_spct <-
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
            allow.scaled = !quantity  %in% c("average", "mean", "total"),
+           naming = "default",
            ...) {
     irrad_spct(spct, w.band = w.band, unit.out = "photon", quantity = quantity,
                time.unit = time.unit,
                scale.factor = scale.factor,
                wb.trim = wb.trim,
                use.cached.mult = use.cached.mult, use.hinges = use.hinges,
-               allow.scaled = allow.scaled)
+               allow.scaled = allow.scaled,
+               naming = naming)
   }
 
 
@@ -540,10 +577,10 @@ q_irrad.source_spct <-
 #'   the boundaries of the wavebands.
 #' @param allow.scaled logical indicating whether scaled or normalized spectra
 #'   as argument to spct are flagged as an error.
+#' @param naming character one of "long", "default", "short" or "none". Used to
+#'   select the type of names to assign to returned value.
 #' @param ... other arguments (possibly used by derived methods).
 #'
-#'
-#'
 #' @export
 #'
 #' @examples
@@ -595,7 +632,9 @@ fluence.source_spct <-
            wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
-           allow.scaled = FALSE, ...) {
+           allow.scaled = FALSE,
+           naming = "default",
+           ...) {
     if (!lubridate::is.duration(exposure.time) &&
         !lubridate::is.period(exposure.time) &&
         !is.numeric(exposure.time) ) {
@@ -609,7 +648,8 @@ fluence.source_spct <-
                    scale.factor = scale.factor,
                    wb.trim = wb.trim,
                    use.cached.mult = use.cached.mult, use.hinges = use.hinges,
-                   allow.scaled = allow.scaled)
+                   allow.scaled = allow.scaled,
+                   naming = naming)
     }
     if (unit.out %in% c("photon", "quantum")) {
       attr(return.value, "radiation.unit") <- "photon fluence (mol m-2)"
@@ -643,6 +683,8 @@ fluence.source_spct <-
 #'   the boundaries of the wavebands.
 #' @param allow.scaled logical indicating whether scaled or normalized spectra
 #'   as argument to spct are flagged as an error.
+#' @param naming character one of "long", "default", "short" or "none". Used to
+#'   select the type of names to assign to returned value.
 #' @param ... other arguments (possibly ignored).
 #'
 #' @examples
@@ -693,7 +735,9 @@ q_fluence.source_spct <-
            wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
-           allow.scaled = FALSE, ...) {
+           allow.scaled = FALSE,
+           naming = "default",
+           ...) {
     if (!lubridate::is.duration(exposure.time) &&
         !lubridate::is.period(exposure.time) &&
         !is.numeric(exposure.time) ) {
@@ -707,7 +751,8 @@ q_fluence.source_spct <-
                    scale.factor = scale.factor,
                    wb.trim = wb.trim,
                    use.cached.mult = use.cached.mult, use.hinges = use.hinges,
-                   allow.scaled = allow.scaled)
+                   allow.scaled = allow.scaled,
+                   naming = naming)
     }
     attr(return.value, "radiation.unit") <- "photon fluence (mol m-2)"
     attr(return.value, "exposure.duration") <- exposure.time
@@ -737,6 +782,8 @@ q_fluence.source_spct <-
 #'   the boundaries of the wavebands.
 #' @param allow.scaled logical indicating whether scaled or normalized spectra
 #'   as argument to spct are flagged as an error
+#' @param naming character one of "long", "default", "short" or "none". Used to
+#'   select the type of names to assign to returned value.
 #' @param ... other arguments (possibly ignored)
 #'
 #' @examples
@@ -785,7 +832,9 @@ e_fluence.source_spct <-
            wb.trim = getOption("photobiology.waveband.trim", default = TRUE),
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
-           allow.scaled = FALSE, ...) {
+           allow.scaled = FALSE,
+           naming = "default",
+           ...) {
     if (!lubridate::is.duration(exposure.time) &&
         !lubridate::is.period(exposure.time) &&
         !is.numeric(exposure.time) ) {
@@ -799,7 +848,8 @@ e_fluence.source_spct <-
                    scale.factor = scale.factor,
                    wb.trim = wb.trim,
                    use.cached.mult = use.cached.mult, use.hinges = use.hinges,
-                   allow.scaled = allow.scaled)
+                   allow.scaled = allow.scaled,
+                   naming = naming)
     }
     attr(return.value, "radiation.unit") <- "energy fluence (J m-2)"
     attr(return.value, "exposure.duration") <- exposure.time
@@ -835,6 +885,7 @@ irrad.source_mspct <-
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
            allow.scaled = !quantity  %in% c("average", "mean", "total"),
+           naming = "default",
            ...,
            attr2tb = NULL,
            idx = "spct.idx",
@@ -853,6 +904,7 @@ irrad.source_mspct <-
         use.cached.mult = use.cached.mult,
         use.hinges = use.hinges,
         allow.scaled = allow.scaled,
+        naming = naming,
         idx = idx,
         col.names = names(w.band),
         .parallel = .parallel,
@@ -889,6 +941,7 @@ q_irrad.source_mspct <-
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
            allow.scaled = !quantity  %in% c("average", "mean", "total"),
+           naming = "default",
            ...,
            attr2tb = NULL,
            idx = "spct.idx",
@@ -906,6 +959,7 @@ q_irrad.source_mspct <-
         use.cached.mult = use.cached.mult,
         use.hinges = use.hinges,
         allow.scaled = allow.scaled,
+        naming = naming,
         idx = idx,
         col.names = names(w.band),
         .parallel = .parallel,
@@ -942,6 +996,7 @@ e_irrad.source_mspct <-
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
            allow.scaled = !quantity  %in% c("average", "mean", "total"),
+           naming = "default",
            ...,
            attr2tb = NULL,
            idx = "spct.idx",
@@ -959,6 +1014,7 @@ e_irrad.source_mspct <-
         use.cached.mult = use.cached.mult,
         use.hinges = use.hinges,
         allow.scaled = allow.scaled,
+        naming = naming,
         idx = idx,
         col.names = names(w.band),
         .parallel = .parallel,
@@ -995,6 +1051,7 @@ fluence.source_mspct <-
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
            allow.scaled = FALSE,
+           naming = "default",
            ...,
            attr2tb = NULL,
            idx = "spct.idx",
@@ -1012,6 +1069,7 @@ fluence.source_mspct <-
         use.cached.mult = use.cached.mult,
         use.hinges = use.hinges,
         allow.scaled = allow.scaled,
+        naming = naming,
         idx = idx,
         col.names = names(w.band),
         .parallel = .parallel,
@@ -1098,6 +1156,7 @@ q_fluence.source_mspct <-
            use.cached.mult = getOption("photobiology.use.cached.mult", default = FALSE),
            use.hinges = NULL,
            allow.scaled = FALSE,
+           naming = "default",
            ...,
            attr2tb = NULL,
            idx = "spct.idx",
@@ -1114,6 +1173,7 @@ q_fluence.source_mspct <-
         use.cached.mult = use.cached.mult,
         use.hinges = use.hinges,
         allow.scaled = allow.scaled,
+        naming = naming,
         idx = idx,
         col.names = names(w.band),
         .parallel = .parallel,
